#ifndef DETECTOR_H
#define DETECTOR_H
const char * run_detector (const char * buf, int len);
#endif /* ndef DETECTOR_H */
